herror

Function herror 

#[unsafe(no_mangle)]
pub extern "C" fn herror(prefix: *const c_char)
👎Deprecated
Print error message associated with H_ERRNO to stderr.

Arguments

  • prefix - An optional prefix to prepend to the error message. May be null or an empty ("") C string.

Safety

Like crate::header::stdio::perror, prefix should be a valid, NUL terminated C string if used. The caller may safely call this function with a null pointer.

Deprecation

H_ERRNO, hstrerror, herror, and other functions are deprecated as of POSIX.1-2001 and removed as of POSIX.1-2008. These functions are provided for backwards compatibility but should not be used by new code.